// Copyright 1998-2014 Epic Games, Inc. All Rights Reserved.

#pragma once

#include "SlateWidgetStyleContainerBase.h"
#include "SkillButtonStyle.generated.h"

/**
* Represents the appearance of an SShooterScoreboardWidget
*/
USTRUCT()
struct GUILIBRARY_API FSkillButtonWidgetStyle : public FSlateWidgetStyle
{
	GENERATED_USTRUCT_BODY()

	FSkillButtonWidgetStyle();
	virtual ~FSkillButtonWidgetStyle();

	// FSlateWidgetStyle
	virtual void GetResources(TArray<const FSlateBrush*>& OutBrushes) const override;
	static const FName TypeName;
	virtual const FName GetTypeName() const override{ return TypeName; };
	static const FSkillButtonWidgetStyle& GetDefault();

	/** Set button height manually. Note that it cant be smaller than MinSlotHeight of SkillsPanel this button is part of. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	float ButtonHeightOverride;
	FSkillButtonWidgetStyle& SetButtonHeight(const float& InMinSlotHeight) { ButtonHeightOverride = InMinSlotHeight; return *this; }

	/** Set button width manually. Note that it cant be smaller than MinSlotWidth of SkillsPanel this button is part of. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	float ButtonWidthOverride;
	FSkillButtonWidgetStyle& SetButtonWidth(const float& InMinSlotWidth) { ButtonWidthOverride = InMinSlotWidth; return *this; }

	/** Default Button style. Note: For some reason 'Disabled' state of FButtonStyle is not used. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FButtonStyle ButtonStyle;

	/** Text style of keybinding. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FTextBlockStyle KeyBindingStyle;

	/** Background brush for hotkey text. Used only if bDrawHotkeyText is true. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush HotkeyTextBorderBrush;
	FSkillButtonWidgetStyle& SetItemBorderBrush(const FSlateBrush& InHotkeyTextBorderBrush) { HotkeyTextBorderBrush = InHotkeyTextBorderBrush; return *this; }
};


/**
*/
UCLASS(hidecategories = Object, MinimalAPI)
class USkillButtonStyle : public USlateWidgetStyleContainerBase
{
	GENERATED_UCLASS_BODY()

public:
	/** The actual data describing the scoreboard's appearance. */
	UPROPERTY(Category = Appearance, EditAnywhere, meta = (ShowOnlyInnerProperties))
		FSkillButtonWidgetStyle ResourceBarStyle;

	virtual const struct FSlateWidgetStyle* const GetStyle() const override
	{
		return static_cast< const struct FSlateWidgetStyle* >(&ResourceBarStyle);
	}
};
